@@ -260,12 +260,12 @@ class chatgpt(BaseLLM):
         if self.check_done and done_message:
             done_message.visible = False
             if self.conversation[convo_id][-1][-1].name == "done":
-                done_message[-1].visible = True
+                self.conversation[convo_id][-1][-1].visible = True
 
         # 构造请求数据
         request_data = {
             "model": model or self.engine,
-            "messages": self.conversation[convo_id].render_latest() if pass_history else Messages(
+            "messages": await self.conversation[convo_id].render_latest() if pass_history else Messages(
                 SystemMessage(self.system_prompt, self.conversation[convo_id].provider("files")),
                 UserMessage(prompt)
             ),
